@@ -12,18 +12,18 @@
 #include <math.h>
 #include <sys/time.h>
 
-#include "./sumalibs/libutils/utilities.h"
-#include "./sumalibs/libfasta/sequence.h"
-#include "./sumalibs/libfasta/fasta_header_parser.h"
-#include "./sumalibs/libfasta/fasta_header_handler.h"
-#include "./sumalibs/libfasta/fasta_seq_writer.h"
-#include "./sumalibs/liblcs/upperband.h"
-#include "./sumalibs/liblcs/sse_banded_LCS_alignment.h"
+#include "libutils/utilities.h"
+#include "libfasta/sequence.h"
+#include "libfasta/fasta_header_parser.h"
+#include "libfasta/fasta_header_handler.h"
+#include "libfasta/fasta_seq_writer.h"
+#include "liblcs/upperband.h"
+#include "liblcs/sse_banded_LCS_alignment.h"
 
 #include "mtcompare_sumaclust.h"
 #include "sumaclust.h"
 
-#define VERSION "1.0.31"
+#define VERSION "1.0.34"
 
 
 /* ----------------------------------------------- */
